@@ -1,6 +1,8 @@
 #include <thread>
 
+#ifndef R_NO_REMAP
 #define R_NO_REMAP
+#endif
 
 #include <R.h>
 #include <Rdefines.h>
